from ..broker import Broker


class EndHostMacAddressBroker(Broker):
    controller = "end_host_mac_addresses"

    def index(self, **kwargs):
        """Lists the available end host mac addresses. Any of the inputs listed may be be used to narrow the list; other inputs will be ignored. Of the various ways to query lists, using this method is most efficient.

            **Inputs**

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier for the associated Device record.
             :type DeviceID: Array of Integer

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param EndHostMACAddressID: The internal NetMRI identifier for the End Host MAC Address entry.
             :type EndHostMACAddressID: Array of Integer

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param IPAddress: The IP address of the end host.
             :type IPAddress: Array of String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param InfraDeviceID: The internal NetMRI identifier for the InfraDevice on which the end host was found.
             :type InfraDeviceID: Array of Integer

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param InterfaceID: The internal NetMRI identifier for the interface on which the end host was found.
             :type InterfaceID: Array of Integer

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param MACAddress: The MAC address of the end host.
             :type MACAddress: Array of String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param NeighborID: The internal NetMRI identifier for the associated Neighbor record.
             :type NeighborID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` EndHostMACAddressID

             :param sort: The data field(s) to use for sorting the output. Default is EndHostMACAddressID. Valid values are EndHostMACAddressID, NetworkID, Network, MACAddress, IPAddress, IPAddressNumeric, DataSourceID, DeviceType, DeviceName, DeviceNetBIOSName, DeviceID, ifIndex, InterfaceID, InfraDeviceID, NeighborID, EndHostMACAddressTimestamp, FirstSeenTime, EndHostMACAddressStartTime, EndHostMACAddressEndTime, EndHostMACAddressChangedCols.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each EndHostMacAddress. Valid values are EndHostMACAddressID, NetworkID, Network, MACAddress, IPAddress, IPAddressNumeric, DataSourceID, DeviceType, DeviceName, DeviceNetBIOSName, DeviceID, ifIndex, InterfaceID, InfraDeviceID, NeighborID, EndHostMACAddressTimestamp, FirstSeenTime, EndHostMACAddressStartTime, EndHostMACAddressEndTime, EndHostMACAddressChangedCols. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return end_host_mac_addresses: An array of the EndHostMacAddress objects that match the specified input criteria.
             :rtype end_host_mac_addresses: Array of EndHostMacAddress

            """

        return self.api_list_request(self._get_method_fullname("index"), kwargs)

    def show(self, **kwargs):
        """Shows the details for the specified end host mac address.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param EndHostMACAddressID: The internal NetMRI identifier for the End Host MAC Address entry.
             :type EndHostMACAddressID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return end_host_mac_address: The end host mac address identified by the specified EndHostMACAddressID.
             :rtype end_host_mac_address: EndHostMacAddress

            """

        return self.api_request(self._get_method_fullname("show"), kwargs)

    def search(self, **kwargs):
        """Lists the available end host mac addresses matching the input criteria. This method provides a more flexible search interface than the index method, but searching using this method is more demanding on the system and will not perform to the same level as the index method. The input fields listed below will be used as in the index method, to filter the result, along with the optional query string and XML filter described below.

            **Inputs**

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceID: The internal NetMRI identifier for the collector NetMRI that collected this data record.
             :type DataSourceID: Array of Integer

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier for the associated Device record.
             :type DeviceID: Array of Integer

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceName: The determined name of the end host.
             :type DeviceName: Array of String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceNetBIOSName: The NetBIOS name of the end host.
             :type DeviceNetBIOSName: Array of String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceType: The determined type of the end host.
             :type DeviceType: Array of String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param EndHostMACAddressChangedCols: The fields that changed between this revision of the record and the previous revision.
             :type EndHostMACAddressChangedCols: Array of String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param EndHostMACAddressEndTime: The ending effective time of this record, or empty if still in effect.
             :type EndHostMACAddressEndTime: Array of DateTime

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param EndHostMACAddressID: The internal NetMRI identifier for the End Host MAC Address entry.
             :type EndHostMACAddressID: Array of Integer

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param EndHostMACAddressStartTime: The starting effective time of this record.
             :type EndHostMACAddressStartTime: Array of DateTime

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param EndHostMACAddressTimestamp: The date and time this record was collected or calculated.
             :type EndHostMACAddressTimestamp: Array of DateTime

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param FirstSeenTime: The date and time this record was first seen.
             :type FirstSeenTime: Array of DateTime

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param IPAddress: The IP address of the end host.
             :type IPAddress: Array of String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param IPAddressNumeric: The IP address of the end host, in numerical form.
             :type IPAddressNumeric: Array of Integer

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param InfraDeviceID: The internal NetMRI identifier for the InfraDevice on which the end host was found.
             :type InfraDeviceID: Array of Integer

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param InterfaceID: The internal NetMRI identifier for the interface on which the end host was found.
             :type InterfaceID: Array of Integer

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param MACAddress: The MAC address of the end host.
             :type MACAddress: Array of String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param NeighborID: The internal NetMRI identifier for the associated Neighbor record.
             :type NeighborID: Array of Integer

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param Network: The name of the Network View associated.
             :type Network: Array of String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param NetworkID: The internal NetMRI identifier of the associated network.
             :type NetworkID: Array of Integer

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ifIndex: The interface index on which the end host was found.
             :type ifIndex: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` EndHostMACAddressID

             :param sort: The data field(s) to use for sorting the output. Default is EndHostMACAddressID. Valid values are EndHostMACAddressID, NetworkID, Network, MACAddress, IPAddress, IPAddressNumeric, DataSourceID, DeviceType, DeviceName, DeviceNetBIOSName, DeviceID, ifIndex, InterfaceID, InfraDeviceID, NeighborID, EndHostMACAddressTimestamp, FirstSeenTime, EndHostMACAddressStartTime, EndHostMACAddressEndTime, EndHostMACAddressChangedCols.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each EndHostMacAddress. Valid values are EndHostMACAddressID, NetworkID, Network, MACAddress, IPAddress, IPAddressNumeric, DataSourceID, DeviceType, DeviceName, DeviceNetBIOSName, DeviceID, ifIndex, InterfaceID, InfraDeviceID, NeighborID, EndHostMACAddressTimestamp, FirstSeenTime, EndHostMACAddressStartTime, EndHostMACAddressEndTime, EndHostMACAddressChangedCols. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param query: This value will be matched against end host mac addresses, looking to see if one or more of the listed attributes contain the passed value. You may also surround the value with '/' and '/' to perform a regular expression search rather than a containment operation. Any record that matches will be returned. The attributes searched are: DataSourceID, DeviceID, DeviceName, DeviceNetBIOSName, DeviceType, EndHostMACAddressChangedCols, EndHostMACAddressEndTime, EndHostMACAddressID, EndHostMACAddressStartTime, EndHostMACAddressTimestamp, FirstSeenTime, IPAddress, IPAddressNumeric, InfraDeviceID, InterfaceID, MACAddress, NeighborID, Network, NetworkID, ifIndex.
             :type query: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return end_host_mac_addresses: An array of the EndHostMacAddress objects that match the specified input criteria.
             :rtype end_host_mac_addresses: Array of EndHostMacAddress

            """

        return self.api_list_request(self._get_method_fullname("search"), kwargs)

    def find(self, **kwargs):
        """Lists the available end host mac addresses matching the input specification. This provides the most flexible search specification of all the query mechanisms, enabling searching using comparison operations other than equality. However, it is more complex to use and will not perform as efficiently as the index or search methods. In the input descriptions below, 'field names' refers to the following fields: DataSourceID, DeviceID, DeviceName, DeviceNetBIOSName, DeviceType, EndHostMACAddressChangedCols, EndHostMACAddressEndTime, EndHostMACAddressID, EndHostMACAddressStartTime, EndHostMACAddressTimestamp, FirstSeenTime, IPAddress, IPAddressNumeric, InfraDeviceID, InterfaceID, MACAddress, NeighborID, Network, NetworkID, ifIndex.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DataSourceID: The operator to apply to the field DataSourceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DataSourceID: The internal NetMRI identifier for the collector NetMRI that collected this data record. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DataSourceID: If op_DataSourceID is specified, the field named in this input will be compared to the value in DataSourceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DataSourceID must be specified if op_DataSourceID is specified.
             :type val_f_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DataSourceID: If op_DataSourceID is specified, this value will be compared to the value in DataSourceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DataSourceID must be specified if op_DataSourceID is specified.
             :type val_c_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DeviceID: The operator to apply to the field DeviceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DeviceID: The internal NetMRI identifier for the associated Device record. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DeviceID: If op_DeviceID is specified, the field named in this input will be compared to the value in DeviceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DeviceID must be specified if op_DeviceID is specified.
             :type val_f_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DeviceID: If op_DeviceID is specified, this value will be compared to the value in DeviceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DeviceID must be specified if op_DeviceID is specified.
             :type val_c_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DeviceName: The operator to apply to the field DeviceName. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DeviceName: The determined name of the end host. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DeviceName: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DeviceName: If op_DeviceName is specified, the field named in this input will be compared to the value in DeviceName using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DeviceName must be specified if op_DeviceName is specified.
             :type val_f_DeviceName: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DeviceName: If op_DeviceName is specified, this value will be compared to the value in DeviceName using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DeviceName must be specified if op_DeviceName is specified.
             :type val_c_DeviceName: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DeviceNetBIOSName: The operator to apply to the field DeviceNetBIOSName. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DeviceNetBIOSName: The NetBIOS name of the end host. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DeviceNetBIOSName: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DeviceNetBIOSName: If op_DeviceNetBIOSName is specified, the field named in this input will be compared to the value in DeviceNetBIOSName using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DeviceNetBIOSName must be specified if op_DeviceNetBIOSName is specified.
             :type val_f_DeviceNetBIOSName: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DeviceNetBIOSName: If op_DeviceNetBIOSName is specified, this value will be compared to the value in DeviceNetBIOSName using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DeviceNetBIOSName must be specified if op_DeviceNetBIOSName is specified.
             :type val_c_DeviceNetBIOSName: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DeviceType: The operator to apply to the field DeviceType. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DeviceType: The determined type of the end host. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DeviceType: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DeviceType: If op_DeviceType is specified, the field named in this input will be compared to the value in DeviceType using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DeviceType must be specified if op_DeviceType is specified.
             :type val_f_DeviceType: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DeviceType: If op_DeviceType is specified, this value will be compared to the value in DeviceType using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DeviceType must be specified if op_DeviceType is specified.
             :type val_c_DeviceType: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_EndHostMACAddressChangedCols: The operator to apply to the field EndHostMACAddressChangedCols. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. EndHostMACAddressChangedCols: The fields that changed between this revision of the record and the previous revision. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_EndHostMACAddressChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_EndHostMACAddressChangedCols: If op_EndHostMACAddressChangedCols is specified, the field named in this input will be compared to the value in EndHostMACAddressChangedCols using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_EndHostMACAddressChangedCols must be specified if op_EndHostMACAddressChangedCols is specified.
             :type val_f_EndHostMACAddressChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_EndHostMACAddressChangedCols: If op_EndHostMACAddressChangedCols is specified, this value will be compared to the value in EndHostMACAddressChangedCols using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_EndHostMACAddressChangedCols must be specified if op_EndHostMACAddressChangedCols is specified.
             :type val_c_EndHostMACAddressChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_EndHostMACAddressEndTime: The operator to apply to the field EndHostMACAddressEndTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. EndHostMACAddressEndTime: The ending effective time of this record, or empty if still in effect. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_EndHostMACAddressEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_EndHostMACAddressEndTime: If op_EndHostMACAddressEndTime is specified, the field named in this input will be compared to the value in EndHostMACAddressEndTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_EndHostMACAddressEndTime must be specified if op_EndHostMACAddressEndTime is specified.
             :type val_f_EndHostMACAddressEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_EndHostMACAddressEndTime: If op_EndHostMACAddressEndTime is specified, this value will be compared to the value in EndHostMACAddressEndTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_EndHostMACAddressEndTime must be specified if op_EndHostMACAddressEndTime is specified.
             :type val_c_EndHostMACAddressEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_EndHostMACAddressID: The operator to apply to the field EndHostMACAddressID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. EndHostMACAddressID: The internal NetMRI identifier for the End Host MAC Address entry. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_EndHostMACAddressID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_EndHostMACAddressID: If op_EndHostMACAddressID is specified, the field named in this input will be compared to the value in EndHostMACAddressID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_EndHostMACAddressID must be specified if op_EndHostMACAddressID is specified.
             :type val_f_EndHostMACAddressID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_EndHostMACAddressID: If op_EndHostMACAddressID is specified, this value will be compared to the value in EndHostMACAddressID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_EndHostMACAddressID must be specified if op_EndHostMACAddressID is specified.
             :type val_c_EndHostMACAddressID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_EndHostMACAddressStartTime: The operator to apply to the field EndHostMACAddressStartTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. EndHostMACAddressStartTime: The starting effective time of this record. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_EndHostMACAddressStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_EndHostMACAddressStartTime: If op_EndHostMACAddressStartTime is specified, the field named in this input will be compared to the value in EndHostMACAddressStartTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_EndHostMACAddressStartTime must be specified if op_EndHostMACAddressStartTime is specified.
             :type val_f_EndHostMACAddressStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_EndHostMACAddressStartTime: If op_EndHostMACAddressStartTime is specified, this value will be compared to the value in EndHostMACAddressStartTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_EndHostMACAddressStartTime must be specified if op_EndHostMACAddressStartTime is specified.
             :type val_c_EndHostMACAddressStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_EndHostMACAddressTimestamp: The operator to apply to the field EndHostMACAddressTimestamp. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. EndHostMACAddressTimestamp: The date and time this record was collected or calculated. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_EndHostMACAddressTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_EndHostMACAddressTimestamp: If op_EndHostMACAddressTimestamp is specified, the field named in this input will be compared to the value in EndHostMACAddressTimestamp using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_EndHostMACAddressTimestamp must be specified if op_EndHostMACAddressTimestamp is specified.
             :type val_f_EndHostMACAddressTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_EndHostMACAddressTimestamp: If op_EndHostMACAddressTimestamp is specified, this value will be compared to the value in EndHostMACAddressTimestamp using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_EndHostMACAddressTimestamp must be specified if op_EndHostMACAddressTimestamp is specified.
             :type val_c_EndHostMACAddressTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_FirstSeenTime: The operator to apply to the field FirstSeenTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. FirstSeenTime: The date and time this record was first seen. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_FirstSeenTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_FirstSeenTime: If op_FirstSeenTime is specified, the field named in this input will be compared to the value in FirstSeenTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_FirstSeenTime must be specified if op_FirstSeenTime is specified.
             :type val_f_FirstSeenTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_FirstSeenTime: If op_FirstSeenTime is specified, this value will be compared to the value in FirstSeenTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_FirstSeenTime must be specified if op_FirstSeenTime is specified.
             :type val_c_FirstSeenTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_IPAddress: The operator to apply to the field IPAddress. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. IPAddress: The IP address of the end host. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_IPAddress: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_IPAddress: If op_IPAddress is specified, the field named in this input will be compared to the value in IPAddress using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_IPAddress must be specified if op_IPAddress is specified.
             :type val_f_IPAddress: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_IPAddress: If op_IPAddress is specified, this value will be compared to the value in IPAddress using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_IPAddress must be specified if op_IPAddress is specified.
             :type val_c_IPAddress: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_IPAddressNumeric: The operator to apply to the field IPAddressNumeric. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. IPAddressNumeric: The IP address of the end host, in numerical form. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_IPAddressNumeric: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_IPAddressNumeric: If op_IPAddressNumeric is specified, the field named in this input will be compared to the value in IPAddressNumeric using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_IPAddressNumeric must be specified if op_IPAddressNumeric is specified.
             :type val_f_IPAddressNumeric: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_IPAddressNumeric: If op_IPAddressNumeric is specified, this value will be compared to the value in IPAddressNumeric using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_IPAddressNumeric must be specified if op_IPAddressNumeric is specified.
             :type val_c_IPAddressNumeric: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_InfraDeviceID: The operator to apply to the field InfraDeviceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. InfraDeviceID: The internal NetMRI identifier for the InfraDevice on which the end host was found. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_InfraDeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_InfraDeviceID: If op_InfraDeviceID is specified, the field named in this input will be compared to the value in InfraDeviceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_InfraDeviceID must be specified if op_InfraDeviceID is specified.
             :type val_f_InfraDeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_InfraDeviceID: If op_InfraDeviceID is specified, this value will be compared to the value in InfraDeviceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_InfraDeviceID must be specified if op_InfraDeviceID is specified.
             :type val_c_InfraDeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_InterfaceID: The operator to apply to the field InterfaceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. InterfaceID: The internal NetMRI identifier for the interface on which the end host was found. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_InterfaceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_InterfaceID: If op_InterfaceID is specified, the field named in this input will be compared to the value in InterfaceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_InterfaceID must be specified if op_InterfaceID is specified.
             :type val_f_InterfaceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_InterfaceID: If op_InterfaceID is specified, this value will be compared to the value in InterfaceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_InterfaceID must be specified if op_InterfaceID is specified.
             :type val_c_InterfaceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_MACAddress: The operator to apply to the field MACAddress. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. MACAddress: The MAC address of the end host. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_MACAddress: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_MACAddress: If op_MACAddress is specified, the field named in this input will be compared to the value in MACAddress using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_MACAddress must be specified if op_MACAddress is specified.
             :type val_f_MACAddress: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_MACAddress: If op_MACAddress is specified, this value will be compared to the value in MACAddress using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_MACAddress must be specified if op_MACAddress is specified.
             :type val_c_MACAddress: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_NeighborID: The operator to apply to the field NeighborID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. NeighborID: The internal NetMRI identifier for the associated Neighbor record. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_NeighborID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_NeighborID: If op_NeighborID is specified, the field named in this input will be compared to the value in NeighborID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_NeighborID must be specified if op_NeighborID is specified.
             :type val_f_NeighborID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_NeighborID: If op_NeighborID is specified, this value will be compared to the value in NeighborID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_NeighborID must be specified if op_NeighborID is specified.
             :type val_c_NeighborID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_Network: The operator to apply to the field Network. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. Network: The name of the Network View associated. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_Network: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_Network: If op_Network is specified, the field named in this input will be compared to the value in Network using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_Network must be specified if op_Network is specified.
             :type val_f_Network: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_Network: If op_Network is specified, this value will be compared to the value in Network using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_Network must be specified if op_Network is specified.
             :type val_c_Network: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_NetworkID: The operator to apply to the field NetworkID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. NetworkID: The internal NetMRI identifier of the associated network. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_NetworkID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_NetworkID: If op_NetworkID is specified, the field named in this input will be compared to the value in NetworkID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_NetworkID must be specified if op_NetworkID is specified.
             :type val_f_NetworkID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_NetworkID: If op_NetworkID is specified, this value will be compared to the value in NetworkID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_NetworkID must be specified if op_NetworkID is specified.
             :type val_c_NetworkID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_ifIndex: The operator to apply to the field ifIndex. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. ifIndex: The interface index on which the end host was found. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_ifIndex: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_ifIndex: If op_ifIndex is specified, the field named in this input will be compared to the value in ifIndex using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_ifIndex must be specified if op_ifIndex is specified.
             :type val_f_ifIndex: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_ifIndex: If op_ifIndex is specified, this value will be compared to the value in ifIndex using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_ifIndex must be specified if op_ifIndex is specified.
             :type val_c_ifIndex: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` EndHostMACAddressID

             :param sort: The data field(s) to use for sorting the output. Default is EndHostMACAddressID. Valid values are EndHostMACAddressID, NetworkID, Network, MACAddress, IPAddress, IPAddressNumeric, DataSourceID, DeviceType, DeviceName, DeviceNetBIOSName, DeviceID, ifIndex, InterfaceID, InfraDeviceID, NeighborID, EndHostMACAddressTimestamp, FirstSeenTime, EndHostMACAddressStartTime, EndHostMACAddressEndTime, EndHostMACAddressChangedCols.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each EndHostMacAddress. Valid values are EndHostMACAddressID, NetworkID, Network, MACAddress, IPAddress, IPAddressNumeric, DataSourceID, DeviceType, DeviceName, DeviceNetBIOSName, DeviceID, ifIndex, InterfaceID, InfraDeviceID, NeighborID, EndHostMACAddressTimestamp, FirstSeenTime, EndHostMACAddressStartTime, EndHostMACAddressEndTime, EndHostMACAddressChangedCols. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return end_host_mac_addresses: An array of the EndHostMacAddress objects that match the specified input criteria.
             :rtype end_host_mac_addresses: Array of EndHostMacAddress

            """

        return self.api_list_request(self._get_method_fullname("find"), kwargs)



from ..broker import Broker


class DeviceIpRangeBroker(Broker):
    controller = "device_ip_ranges"

    def show(self, **kwargs):
        """Shows the details for the specified device ip range.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceIPRangeID: The internal NetMRI identifier for ip address range definition.
             :type DeviceIPRangeID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of device ip range methods. The listed methods will be called on each device ip range returned and included in the output. Available methods are: device_object, data_source, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: device_object, data_source, device.
             :type include: Array of String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_ip_range: The device ip range identified by the specified DeviceIPRangeID.
             :rtype device_ip_range: DeviceIpRange

            """

        return self.api_request(self._get_method_fullname("show"), kwargs)

    def index(self, **kwargs):
        """Lists the available device ip ranges. Any of the inputs listed may be be used to narrow the list; other inputs will be ignored. Of the various ways to query lists, using this method is most efficient.

            **Inputs**

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier for the device to which belongs this flow.
             :type DeviceID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceIPRangeID: The internal NetMRI identifier for ip address range definition.
             :type DeviceIPRangeID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceObjectID: The internal NetMRI identifier for the service to which belongs this flow.
             :type DeviceObjectID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the device ip ranges as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of device ip range methods. The listed methods will be called on each device ip range returned and included in the output. Available methods are: device_object, data_source, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: device_object, data_source, device.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DeviceIPRangeID

             :param sort: The data field(s) to use for sorting the output. Default is DeviceIPRangeID. Valid values are DeviceIPRangeID, DeviceID, DeviceObjectID, DataSourceID, IprFirstSeenTime, IprStartTime, IprEndTime, IprTimestamp, IprChangedCols, IprIPVersion, IprDisplayText, IprIPNumericMin, IprIPNumericMax.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each DeviceIpRange. Valid values are DeviceIPRangeID, DeviceID, DeviceObjectID, DataSourceID, IprFirstSeenTime, IprStartTime, IprEndTime, IprTimestamp, IprChangedCols, IprIPVersion, IprDisplayText, IprIPNumericMin, IprIPNumericMax. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_ip_ranges: An array of the DeviceIpRange objects that match the specified input criteria.
             :rtype device_ip_ranges: Array of DeviceIpRange

            """

        return self.api_list_request(self._get_method_fullname("index"), kwargs)

    def search(self, **kwargs):
        """Lists the available device ip ranges matching the input criteria. This method provides a more flexible search interface than the index method, but searching using this method is more demanding on the system and will not perform to the same level as the index method. The input fields listed below will be used as in the index method, to filter the result, along with the optional query string and XML filter described below.

            **Inputs**

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceID: The internal NetMRI identifier for the collector NetMRI that collected this data record.
             :type DataSourceID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier for the device to which belongs this flow.
             :type DeviceID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceIPRangeID: The internal NetMRI identifier for ip address range definition.
             :type DeviceIPRangeID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceObjectID: The internal NetMRI identifier for the service to which belongs this flow.
             :type DeviceObjectID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param IprChangedCols: The fields that changed between this revision of the record and the previous revision.
             :type IprChangedCols: Array of String

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param IprDisplayText: The text that was defined in the configuration for this ip address range.
             :type IprDisplayText: Array of String

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param IprEndTime: The ending effective time of this record, or empty if still in effect.
             :type IprEndTime: Array of DateTime

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param IprFirstSeenTime: The timestamp of when NetMRI saw for the first time this flow.
             :type IprFirstSeenTime: Array of DateTime

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param IprIPNumericMax: The numeric value for the range max value.
             :type IprIPNumericMax: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param IprIPNumericMin: The numeric value for the range min value.
             :type IprIPNumericMin: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param IprIPVersion: The ip version for this range. 4 or 6.
             :type IprIPVersion: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param IprStartTime: The starting effective time of this record.
             :type IprStartTime: Array of DateTime

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param IprTimestamp: The date and time this record was collected or calculated.
             :type IprTimestamp: Array of DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the device ip ranges as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of device ip range methods. The listed methods will be called on each device ip range returned and included in the output. Available methods are: device_object, data_source, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: device_object, data_source, device.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DeviceIPRangeID

             :param sort: The data field(s) to use for sorting the output. Default is DeviceIPRangeID. Valid values are DeviceIPRangeID, DeviceID, DeviceObjectID, DataSourceID, IprFirstSeenTime, IprStartTime, IprEndTime, IprTimestamp, IprChangedCols, IprIPVersion, IprDisplayText, IprIPNumericMin, IprIPNumericMax.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each DeviceIpRange. Valid values are DeviceIPRangeID, DeviceID, DeviceObjectID, DataSourceID, IprFirstSeenTime, IprStartTime, IprEndTime, IprTimestamp, IprChangedCols, IprIPVersion, IprDisplayText, IprIPNumericMin, IprIPNumericMax. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param query: This value will be matched against device ip ranges, looking to see if one or more of the listed attributes contain the passed value. You may also surround the value with '/' and '/' to perform a regular expression search rather than a containment operation. Any record that matches will be returned. The attributes searched are: DataSourceID, DeviceID, DeviceIPRangeID, DeviceObjectID, IprChangedCols, IprDisplayText, IprEndTime, IprFirstSeenTime, IprIPNumericMax, IprIPNumericMin, IprIPVersion, IprStartTime, IprTimestamp.
             :type query: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_ip_ranges: An array of the DeviceIpRange objects that match the specified input criteria.
             :rtype device_ip_ranges: Array of DeviceIpRange

            """

        return self.api_list_request(self._get_method_fullname("search"), kwargs)

    def find(self, **kwargs):
        """Lists the available device ip ranges matching the input specification. This provides the most flexible search specification of all the query mechanisms, enabling searching using comparison operations other than equality. However, it is more complex to use and will not perform as efficiently as the index or search methods. In the input descriptions below, 'field names' refers to the following fields: DataSourceID, DeviceID, DeviceIPRangeID, DeviceObjectID, IprChangedCols, IprDisplayText, IprEndTime, IprFirstSeenTime, IprIPNumericMax, IprIPNumericMin, IprIPVersion, IprStartTime, IprTimestamp.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DataSourceID: The operator to apply to the field DataSourceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DataSourceID: The internal NetMRI identifier for the collector NetMRI that collected this data record. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DataSourceID: If op_DataSourceID is specified, the field named in this input will be compared to the value in DataSourceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DataSourceID must be specified if op_DataSourceID is specified.
             :type val_f_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DataSourceID: If op_DataSourceID is specified, this value will be compared to the value in DataSourceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DataSourceID must be specified if op_DataSourceID is specified.
             :type val_c_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DeviceID: The operator to apply to the field DeviceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DeviceID: The internal NetMRI identifier for the device to which belongs this flow. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DeviceID: If op_DeviceID is specified, the field named in this input will be compared to the value in DeviceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DeviceID must be specified if op_DeviceID is specified.
             :type val_f_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DeviceID: If op_DeviceID is specified, this value will be compared to the value in DeviceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DeviceID must be specified if op_DeviceID is specified.
             :type val_c_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DeviceIPRangeID: The operator to apply to the field DeviceIPRangeID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DeviceIPRangeID: The internal NetMRI identifier for ip address range definition. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DeviceIPRangeID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DeviceIPRangeID: If op_DeviceIPRangeID is specified, the field named in this input will be compared to the value in DeviceIPRangeID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DeviceIPRangeID must be specified if op_DeviceIPRangeID is specified.
             :type val_f_DeviceIPRangeID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DeviceIPRangeID: If op_DeviceIPRangeID is specified, this value will be compared to the value in DeviceIPRangeID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DeviceIPRangeID must be specified if op_DeviceIPRangeID is specified.
             :type val_c_DeviceIPRangeID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DeviceObjectID: The operator to apply to the field DeviceObjectID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DeviceObjectID: The internal NetMRI identifier for the service to which belongs this flow. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DeviceObjectID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DeviceObjectID: If op_DeviceObjectID is specified, the field named in this input will be compared to the value in DeviceObjectID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DeviceObjectID must be specified if op_DeviceObjectID is specified.
             :type val_f_DeviceObjectID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DeviceObjectID: If op_DeviceObjectID is specified, this value will be compared to the value in DeviceObjectID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DeviceObjectID must be specified if op_DeviceObjectID is specified.
             :type val_c_DeviceObjectID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_IprChangedCols: The operator to apply to the field IprChangedCols. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. IprChangedCols: The fields that changed between this revision of the record and the previous revision. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_IprChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_IprChangedCols: If op_IprChangedCols is specified, the field named in this input will be compared to the value in IprChangedCols using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_IprChangedCols must be specified if op_IprChangedCols is specified.
             :type val_f_IprChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_IprChangedCols: If op_IprChangedCols is specified, this value will be compared to the value in IprChangedCols using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_IprChangedCols must be specified if op_IprChangedCols is specified.
             :type val_c_IprChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_IprDisplayText: The operator to apply to the field IprDisplayText. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. IprDisplayText: The text that was defined in the configuration for this ip address range. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_IprDisplayText: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_IprDisplayText: If op_IprDisplayText is specified, the field named in this input will be compared to the value in IprDisplayText using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_IprDisplayText must be specified if op_IprDisplayText is specified.
             :type val_f_IprDisplayText: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_IprDisplayText: If op_IprDisplayText is specified, this value will be compared to the value in IprDisplayText using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_IprDisplayText must be specified if op_IprDisplayText is specified.
             :type val_c_IprDisplayText: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_IprEndTime: The operator to apply to the field IprEndTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. IprEndTime: The ending effective time of this record, or empty if still in effect. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_IprEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_IprEndTime: If op_IprEndTime is specified, the field named in this input will be compared to the value in IprEndTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_IprEndTime must be specified if op_IprEndTime is specified.
             :type val_f_IprEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_IprEndTime: If op_IprEndTime is specified, this value will be compared to the value in IprEndTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_IprEndTime must be specified if op_IprEndTime is specified.
             :type val_c_IprEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_IprFirstSeenTime: The operator to apply to the field IprFirstSeenTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. IprFirstSeenTime: The timestamp of when NetMRI saw for the first time this flow. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_IprFirstSeenTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_IprFirstSeenTime: If op_IprFirstSeenTime is specified, the field named in this input will be compared to the value in IprFirstSeenTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_IprFirstSeenTime must be specified if op_IprFirstSeenTime is specified.
             :type val_f_IprFirstSeenTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_IprFirstSeenTime: If op_IprFirstSeenTime is specified, this value will be compared to the value in IprFirstSeenTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_IprFirstSeenTime must be specified if op_IprFirstSeenTime is specified.
             :type val_c_IprFirstSeenTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_IprIPNumericMax: The operator to apply to the field IprIPNumericMax. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. IprIPNumericMax: The numeric value for the range max value. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_IprIPNumericMax: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_IprIPNumericMax: If op_IprIPNumericMax is specified, the field named in this input will be compared to the value in IprIPNumericMax using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_IprIPNumericMax must be specified if op_IprIPNumericMax is specified.
             :type val_f_IprIPNumericMax: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_IprIPNumericMax: If op_IprIPNumericMax is specified, this value will be compared to the value in IprIPNumericMax using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_IprIPNumericMax must be specified if op_IprIPNumericMax is specified.
             :type val_c_IprIPNumericMax: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_IprIPNumericMin: The operator to apply to the field IprIPNumericMin. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. IprIPNumericMin: The numeric value for the range min value. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_IprIPNumericMin: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_IprIPNumericMin: If op_IprIPNumericMin is specified, the field named in this input will be compared to the value in IprIPNumericMin using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_IprIPNumericMin must be specified if op_IprIPNumericMin is specified.
             :type val_f_IprIPNumericMin: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_IprIPNumericMin: If op_IprIPNumericMin is specified, this value will be compared to the value in IprIPNumericMin using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_IprIPNumericMin must be specified if op_IprIPNumericMin is specified.
             :type val_c_IprIPNumericMin: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_IprIPVersion: The operator to apply to the field IprIPVersion. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. IprIPVersion: The ip version for this range. 4 or 6. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_IprIPVersion: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_IprIPVersion: If op_IprIPVersion is specified, the field named in this input will be compared to the value in IprIPVersion using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_IprIPVersion must be specified if op_IprIPVersion is specified.
             :type val_f_IprIPVersion: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_IprIPVersion: If op_IprIPVersion is specified, this value will be compared to the value in IprIPVersion using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_IprIPVersion must be specified if op_IprIPVersion is specified.
             :type val_c_IprIPVersion: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_IprStartTime: The operator to apply to the field IprStartTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. IprStartTime: The starting effective time of this record. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_IprStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_IprStartTime: If op_IprStartTime is specified, the field named in this input will be compared to the value in IprStartTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_IprStartTime must be specified if op_IprStartTime is specified.
             :type val_f_IprStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_IprStartTime: If op_IprStartTime is specified, this value will be compared to the value in IprStartTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_IprStartTime must be specified if op_IprStartTime is specified.
             :type val_c_IprStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_IprTimestamp: The operator to apply to the field IprTimestamp. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. IprTimestamp: The date and time this record was collected or calculated. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_IprTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_IprTimestamp: If op_IprTimestamp is specified, the field named in this input will be compared to the value in IprTimestamp using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_IprTimestamp must be specified if op_IprTimestamp is specified.
             :type val_f_IprTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_IprTimestamp: If op_IprTimestamp is specified, this value will be compared to the value in IprTimestamp using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_IprTimestamp must be specified if op_IprTimestamp is specified.
             :type val_c_IprTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the device ip ranges as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of device ip range methods. The listed methods will be called on each device ip range returned and included in the output. Available methods are: device_object, data_source, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: device_object, data_source, device.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DeviceIPRangeID

             :param sort: The data field(s) to use for sorting the output. Default is DeviceIPRangeID. Valid values are DeviceIPRangeID, DeviceID, DeviceObjectID, DataSourceID, IprFirstSeenTime, IprStartTime, IprEndTime, IprTimestamp, IprChangedCols, IprIPVersion, IprDisplayText, IprIPNumericMin, IprIPNumericMax.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each DeviceIpRange. Valid values are DeviceIPRangeID, DeviceID, DeviceObjectID, DataSourceID, IprFirstSeenTime, IprStartTime, IprEndTime, IprTimestamp, IprChangedCols, IprIPVersion, IprDisplayText, IprIPNumericMin, IprIPNumericMax. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_ip_ranges: An array of the DeviceIpRange objects that match the specified input criteria.
             :rtype device_ip_ranges: Array of DeviceIpRange

            """

        return self.api_list_request(self._get_method_fullname("find"), kwargs)

    def device_object(self, **kwargs):
        """the network object to which belongs this ip address range.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceIPRangeID: The internal NetMRI identifier for ip address range definition.
             :type DeviceIPRangeID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : the network object to which belongs this ip address range.
             :rtype : DeviceObject

            """

        return self.api_request(self._get_method_fullname("device_object"), kwargs)

    def data_source(self, **kwargs):
        """The collector NetMRI that collected this data record.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceIPRangeID: The internal NetMRI identifier for ip address range definition.
             :type DeviceIPRangeID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : The collector NetMRI that collected this data record.
             :rtype : DataSource

            """

        return self.api_request(self._get_method_fullname("data_source"), kwargs)

    def device(self, **kwargs):
        """The device from which this data was collected.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceIPRangeID: The internal NetMRI identifier for ip address range definition.
             :type DeviceIPRangeID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : The device from which this data was collected.
             :rtype : Device

            """

        return self.api_request(self._get_method_fullname("device"), kwargs)



from ..remote import RemoteModel


class DataSourceRemote(RemoteModel):
    """
    The NetMRI devices in this deployment.


    |  ``DataSourceID:`` The internal NetMRI identifier for this data source.
    |  ``attribute type:`` number

    |  ``DataSourceStartTime:`` The starting effective time of this revision of the record.
    |  ``attribute type:`` datetime

    |  ``DataSourceEndTime:`` The ending effective time of this revision of this record, or empty if still in effect.
    |  ``attribute type:`` datetime

    |  ``DataSourceChangedCols:`` The fields that changed between this revision of the record and the previous revision.
    |  ``attribute type:`` string

    |  ``DataSourceTimestamp:`` The date and time this record was collected or calculated.
    |  ``attribute type:`` datetime

    |  ``Network:`` The network to which this data source is assigned.
    |  ``attribute type:`` string

    |  ``DataSourceName:`` The name of this data source.
    |  ``attribute type:`` string

    |  ``DataSourceIPDotted:`` The IP address of this data source, in dotted notation.
    |  ``attribute type:`` string

    |  ``DataSourceIPNumeric:`` The numerical IP address of this data source.
    |  ``attribute type:`` number

    |  ``DataSourcePrivateIPDotted:`` Another IP address for the data source, in dotted notation.
    |  ``attribute type:`` string

    |  ``DataSourcePrivateIPNumeric:`` The numerical version of the alternate IP address.
    |  ``attribute type:`` number

    |  ``DataSourceSerialNo:`` The serial number of the collector.
    |  ``attribute type:`` string

    |  ``network_name:`` The name of the Network View associated.
    |  ``attribute type:`` string

    """

    properties = ("DataSourceID",
                  "DataSourceStartTime",
                  "DataSourceEndTime",
                  "DataSourceChangedCols",
                  "DataSourceTimestamp",
                  "Network",
                  "DataSourceName",
                  "DataSourceIPDotted",
                  "DataSourceIPNumeric",
                  "DataSourcePrivateIPDotted",
                  "DataSourcePrivateIPNumeric",
                  "DataSourceSerialNo",
                  "network_name",
                  )



from ..broker import Broker


class AccessObjectsBroker(Broker):
    controller = "access_objects"

    def children(self, **kwargs):
        """Returns tree-format information about this children of a node, in a tree view.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DeviceObject

             :param tree_type: types of objects in the tree, one of ["DeviceObject", "DeviceService"]
             :type tree_type: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` normal

             :param search_mode: kind of search within the object of the database
             :type search_mode: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param search_key: Search identifier for contextual search process. Used only for contextual search.
             :type search_key: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:``

             :param search: String to search in the objects names or direct values
             :type search: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` none

             :param group_mode: organization of tree-view result
             :type group_mode: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param parent_node_id: identifier of an existing node of the tree, for which we want the children nodes, if omitted, parent is the absolute root node of the tree
             :type parent_node_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: Position of the first node of the returned array, in the brotherhood
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 50

             :param limit: Maximum number of nodes expected to return
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` tree

             :param formatting: output format. only one value 'tree'
             :type formatting: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return children: list of node. Each one is a hash [id, node_type, label, tooltip, icon, has_details, leaf, children] representing a child's node
             :rtype children: Array

            """

        return self.api_request(self._get_method_fullname("children"), kwargs)

    def cancel_search(self, **kwargs):
        """Cancels background search processes. Currently only works for contextual search.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param search_key: Search identifier for contextual search process. Used only for contextual search.
             :type search_key: String

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("cancel_search"), kwargs)

    def parents(self, **kwargs):
        """Returns the parents of this node.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param object_id: The tree node id for which we want the parents
             :type object_id: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return parents: list of parents.
             :rtype parents: Array

            """

        return self.api_request(self._get_method_fullname("parents"), kwargs)

    def to_detail(self, **kwargs):
        """Returns the detail for an object.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param object_id: None
             :type object_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param view: 0=tostring, 1=tooltip, 2-popup
             :type view: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return detail: None
             :rtype detail: String

            """

        return self.api_request(self._get_method_fullname("to_detail"), kwargs)

    def object_picker(self, **kwargs):
        """Returns a tree-format of the full sub-tree for this node. Expected to be displayed as a separate tree in a tree-popup window

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DeviceObject

             :param main_type: types of objects searched, one of ["DeviceObject", "DeviceService"]
             :type main_type: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param query: query string for matching fields
             :type query: String

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("object_picker"), kwargs)



from ..remote import RemoteModel


class AuthServerRemote(RemoteModel):
    """
    This table list out the entries of Authentication Servers.


    |  ``id:`` The authentication server identifier.
    |  ``attribute type:`` number

    |  ``priority:`` Priority assigned to an authentication server.
    |  ``attribute type:`` number

    |  ``enabled_ind:`` A flag indicating whether the authentication server settings is enabled or disabled.
    |  ``attribute type:`` bool

    |  ``auth_server:`` Authentication Server Name (required for Radius, Tacacs, LDAP and Active Directory methods).
    |  ``attribute type:`` string

    |  ``auth_port:`` Authentication Port (required for Active Directory method).
    |  ``attribute type:`` number

    |  ``auth_shared_secret:`` The shared secret of an authentication server (required for Radius and Tacacs methods).
    |  ``attribute type:`` string

    |  ``auth_encryption:`` The Encryption method (none or SSL) (required for Active Directory method).
    |  ``attribute type:`` string

    |  ``auth_cert:`` The SSL certificate of an Authentication Server. (Required for Active Directory method).
    |  ``attribute type:`` string

    |  ``auth_timeout:`` The timeout interval of an authentication server settings (Required for Active Directory method).
    |  ``attribute type:`` number

    |  ``created_at:`` The date and time the record was initially created in NetMRI.
    |  ``attribute type:`` datetime

    |  ``updated_at:`` The date and time the record was last modified in NetMRI.
    |  ``attribute type:`` datetime

    |  ``secure_version:`` Internal encrypt version used for any auth_shared_secret
    |  ``attribute type:`` number

    |  ``auth_service_id:`` The id of the authentication service, this server is member of.
    |  ``attribute type:`` number

    |  ``auth_protocol:`` The password exchange protocol to use for authentication. One of (PAP, CHAP)
    |  ``attribute type:`` string

    |  ``source_interface_id:`` The NetMRI interface to use as source of the packets sent to the authentication server.
    |  ``attribute type:`` number

    |  ``auth_version:`` The version use for the authentication (LDAP).
    |  ``attribute type:`` number

    """

    properties = ("id",
                  "priority",
                  "enabled_ind",
                  "auth_server",
                  "auth_port",
                  "auth_shared_secret",
                  "auth_encryption",
                  "auth_cert",
                  "auth_timeout",
                  "created_at",
                  "updated_at",
                  "secure_version",
                  "auth_service_id",
                  "auth_protocol",
                  "source_interface_id",
                  "auth_version",
                  )



from ..remote import RemoteModel


class AuthServerGridRemote(RemoteModel):
    """



    |  ``id:`` none
    |  ``attribute type:`` string

    |  ``priority:`` none
    |  ``attribute type:`` string

    |  ``auth_server:`` none
    |  ``attribute type:`` string

    |  ``auth_port:`` none
    |  ``attribute type:`` string

    |  ``auth_encryption:`` none
    |  ``attribute type:`` string

    |  ``auth_cert:`` none
    |  ``attribute type:`` string

    |  ``certificate:`` none
    |  ``attribute type:`` string

    |  ``ocsp_certs:`` none
    |  ``attribute type:`` string

    |  ``interface:`` none
    |  ``attribute type:`` string

    |  ``status:`` none
    |  ``attribute type:`` string

    |  ``auth_shared_secret:`` none
    |  ``attribute type:`` string

    |  ``enabled_ind:`` none
    |  ``attribute type:`` string

    |  ``auth_version:`` none
    |  ``attribute type:`` string

    |  ``source_interface_id:`` none
    |  ``attribute type:`` string

    """

    properties = ("id",
                  "priority",
                  "auth_server",
                  "auth_port",
                  "auth_encryption",
                  "auth_cert",
                  "certificate",
                  "ocsp_certs",
                  "interface",
                  "status",
                  "auth_shared_secret",
                  "enabled_ind",
                  "auth_version",
                  "source_interface_id",
                  )



from ..broker import Broker


class SystemBackupBroker(Broker):
    controller = "system_backup"

    def create_archive(self, **kwargs):
        """Creates backup of current system database.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include_date: Defines whether include date in file name or not.
             :type include_date: Boolean

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` False

             :param init: Defines whether to initially create the archive.
             :type init: Boolean

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` False

             :param async_ind: When false, backup creating will be run synchronously, and the API call will block until it is complete. When true, backup creating id will be returned to use for subsequent calls
             :type async_ind: Boolean

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("create_archive"), kwargs)

    def create_archive_status(self, **kwargs):
        """Backup database status.

            **Inputs**

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("create_archive_status"), kwargs)

    def ssh_authentication_test(self, **kwargs):
        """Test SSH authentication.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param host: Host name or IP address of the system where archive will be copied.
             :type host: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param port: Number of open SSH port on the system where archive will be delivered. Default value is 22 (used if no port number specified).
             :type port: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param user_name: Name of the existing user on the system where archive will be copied.
             :type user_name: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:``

             :param password: User password on the system where archive will be copied.
             :type password: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` False

             :param use_ssh_keys: Specifies whether to use SSH keys.
             :type use_ssh_keys: Boolean

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param directory: Remote host directory where archive will be stored.
             :type directory: String

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("ssh_authentication_test"), kwargs)

    def move_archive_to_remote_host(self, **kwargs):
        """Moves database archive to remote host via SSH. Note that archive will be removed from NetMRI.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param host: Host name or IP address of the system where archive will be copied. Required if init is set to true.
             :type host: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param port: Number of open SSH port on the system where archive will be delivered. Default value is 22 (used if no port number specified).
             :type port: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param user_name: Name of the existing user on the system where archive will be copied. Required if init is set to true.
             :type user_name: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:``

             :param password: User password on the system where archive will be copied. Required if init is set to true.
             :type password: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` False

             :param use_ssh_keys: Specifies whether to use SSH keys.
             :type use_ssh_keys: Boolean

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param directory: Specifies directory where archive will be stored on remote host. Default is user home directory.
             :type directory: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param init: Set to true to initialize moving archive
             :type init: Boolean

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("move_archive_to_remote_host"), kwargs)

    def download_archive(self, **kwargs):
        """Download database archive.

            **Inputs**

            **Outputs**

            """

        return self.api_mixed_request(self._get_method_fullname("download_archive"), kwargs)

    def download_archive_md5_sum(self, **kwargs):
        """Download database archive md5 checksum.

            **Inputs**

            **Outputs**

            """

        return self.api_mixed_request(self._get_method_fullname("download_archive_md5_sum"), kwargs)

    def remove_archive(self, **kwargs):
        """Database archive is stored in temporary directory on NetMRI. It's removed on schedule but you may choose to force remove it.

            **Inputs**

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("remove_archive"), kwargs)

    def schedule_archiving(self, **kwargs):
        """Schedule NetMRI database archiving. Archive will be stored on up to 2 systems supporting SCP.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param enable: Specifies whether scheduled archiving should be enabled or not. If parameter is not specified then scheduled archiving is set disabled.
             :type enable: Boolean

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param host_1: Host name or IP address of the system where archive will be copied.
             :type host_1: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param port_1: Number of open SSH port on the system where archive will be delivered. Default value is 22 (used if no port number specified).
             :type port_1: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param user_name_1: Name of the existing user on the system where archive will be copied.
             :type user_name_1: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:``

             :param password_1: User password on the system where archive will be copied.
             :type password_1: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` False

             :param use_ssh_keys_1: Specifies whether to use SSH keys.
             :type use_ssh_keys_1: Boolean

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param directory_1: Specifies directory where archive will be stored on remote host. Default is user home directory.
             :type directory_1: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param host_2: Host name or IP address of the system where archive will be copied.
             :type host_2: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param port_2: Number of open SSH port on the system where archive will be delivered. Default value is 22 (used if no port number specified).
             :type port_2: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param user_name_2: Name of the existing user on the system where archive will be copied.
             :type user_name_2: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:``

             :param password_2: User password on the system where archive will be copied.
             :type password_2: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` False

             :param use_ssh_keys_2: Specifies whether to use SSH keys.
             :type use_ssh_keys_2: Boolean

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param directory_2: Specifies directory where archive will be stored on remote host. Default is user home directory.
             :type directory_2: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include_date_1: Specifies whether to put current date into archive file name or not while saving on remote host 1.
             :type include_date_1: Boolean

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include_date_2: Specifies whether to put current date into archive file name or not while saving on remote host 2.
             :type include_date_2: Boolean

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param schedule_cron: Cron schedule string.
             :type schedule_cron: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param schedule_json: NetMRI internal parameters generated by 'cronscheduler' form transmitted in json format for setting cron schedule string.
             :type schedule_json: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` False

             :param force_save: If true, changes will be saved even if credentials test failed
             :type force_save: Boolean

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("schedule_archiving"), kwargs)

    def upload_archive(self, **kwargs):
        """Upload database archive to NetMRI.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param archive: NetMRI database archive file.
             :type archive: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param md5: NetMRI database archive MD5 checksum file.
             :type md5: String

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("upload_archive"), kwargs)

    def restore_database(self, **kwargs):
        """Restores database from the archive which should have been uploaded to NetMRI.

            **Inputs**

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("restore_database"), kwargs)
